@@ -20,12 +20,12 @@ if (length(strsplit(packageDescription("antaresRead")$Version, "\\.")[[1]]) > 3)
 # the R CMD CHECK before package is correctly installed and tests actually run. 
 # The following "if" prevents errors at this step
 if (sourcedir != "") {
-  if (Sys.info()['sysname'] == "Windows") {
-    untar(file.path(sourcedir, "antares-test-study.tar.gz"), exdir = path, 
-          extras = "--force-local")
-  } else {
+  # if (Sys.info()['sysname'] == "Windows") {
+  #   untar(file.path(sourcedir, "antares-test-study.tar.gz"), exdir = path, 
+  #         extras = "--force-local")
+  # } else {
     untar(file.path(sourcedir, "antares-test-study.tar.gz"), exdir = path)
-  }
+  # }
   
   if(.requireRhdf5_Antares(stopP = FALSE) & .runH5Test){
     
